@@ -268,11 +268,11 @@ type (
 	}
 	Head struct {
 		Kind  string `json:"kind" unpack:""`
-		Count int    `json:"count"`
+		Count Expr   `json:"count"`
 	}
 	Tail struct {
 		Kind  string `json:"kind" unpack:""`
-		Count int    `json:"count"`
+		Count Expr   `json:"count"`
 	}
 	Pass struct {
 		Kind string `json:"kind" unpack:""`
