@@ -2,6 +2,7 @@ package optimizer
 
 import (
 	"encoding/json"
+	"strings"
 
 	"github.com/brimdata/zed/compiler/ast/dag"
 	"github.com/brimdata/zed/order"
@@ -27,8 +28,6 @@ func (o *Optimizer) analyzeOp(op dag.Op, layout order.Layout) (order.Layout, err
 		return layout, nil
 	case *dag.Cut:
 		return analyzeCuts(op.Args, layout), nil
-	case *dag.Pick:
-		return analyzeCuts(op.Args, layout), nil
 	case *dag.Drop:
 		for _, f := range op.Args {
 			if fieldOf(f).Equal(key) {
@@ -211,12 +210,7 @@ func analyzeCuts(assignments []dag.Assignment, layout order.Layout) order.Layout
 }
 
 func fieldKey(f field.Path) string {
-	var b []byte
-	for _, s := range f {
-		b = append(b, s...)
-		b = append(b, 0)
-	}
-	return string(b)
+	return strings.Join(f, "\x00")
 }
 
 func fieldOf(e dag.Expr) field.Path {
