@@ -6,6 +6,7 @@ import (
 	"github.com/brimdata/zed"
 	"github.com/brimdata/zed/zcode"
 	"github.com/brimdata/zed/zson"
+	"golang.org/x/exp/slices"
 )
 
 type Collect struct {
@@ -22,9 +23,7 @@ func (c *Collect) Consume(val *zed.Value) {
 }
 
 func (c *Collect) update(val *zed.Value) {
-	stash := make(zcode.Bytes, len(val.Bytes))
-	copy(stash, val.Bytes)
-	c.values = append(c.values, zed.Value{val.Type, stash})
+	c.values = append(c.values, zed.Value{Type: val.Type, Bytes: slices.Clone(val.Bytes)})
 	c.size += len(val.Bytes)
 	for c.size > MaxValueSize {
 		// XXX See issue #1813.  For now we silently discard entries
@@ -44,7 +43,7 @@ func (c *Collect) Result(zctx *zed.Context) *zed.Value {
 	inner := innerType(zctx, c.values)
 	if union, ok := inner.(*zed.TypeUnion); ok {
 		for _, val := range c.values {
-			zed.BuildUnion(&b, union.Selector(val.Type), val.Bytes)
+			zed.BuildUnion(&b, union.TagOf(val.Type), val.Bytes)
 		}
 	} else {
 		for _, val := range c.values {
