@@ -17,8 +17,7 @@ func (u *Under) Call(ectx zed.Allocator, args []zed.Value) *zed.Value {
 	case *zed.TypeError:
 		return ectx.NewValue(typ.Type, val.Bytes)
 	case *zed.TypeUnion:
-		t, bytes := typ.SplitZNG(val.Bytes)
-		return ectx.NewValue(t, bytes)
+		return ectx.NewValue(typ.Untag(val.Bytes))
 	case *zed.TypeOfType:
 		t, err := u.zctx.LookupByValue(val.Bytes)
 		if err != nil {
