@@ -2,6 +2,7 @@ package op
 
 import (
 	"context"
+	"sync"
 
 	"github.com/brimdata/zed"
 	"github.com/brimdata/zed/zbuf"
@@ -22,8 +23,11 @@ type Result struct {
 type Context struct {
 	context.Context
 	Logger *zap.Logger
-	Zctx   *zed.Context
-	cancel context.CancelFunc
+	// WaitGroup is used to ensure that goroutines complete cleanup work
+	// (e.g., removing temporary files) before Cancel returns.
+	WaitGroup sync.WaitGroup
+	Zctx      *zed.Context
+	cancel    context.CancelFunc
 }
 
 func NewContext(ctx context.Context, zctx *zed.Context, logger *zap.Logger) *Context {
@@ -43,6 +47,9 @@ func DefaultContext() *Context {
 	return NewContext(context.Background(), zed.NewContext(), nil)
 }
 
+// Cancel cancels the context.  Cancel must be called to ensure that operators
+// complete cleanup work (e.g., removing temporary files).
 func (c *Context) Cancel() {
 	c.cancel()
+	c.WaitGroup.Wait()
 }
