@@ -16,8 +16,8 @@ import (
 // will consume.
 var MemMaxBytes = 128 * 1024 * 1024
 
-type Proc struct {
-	pctx       *op.Context
+type Op struct {
+	octx       *op.Context
 	parent     zbuf.Puller
 	order      order.Which
 	nullsFirst bool
@@ -32,9 +32,9 @@ type Proc struct {
 	sorter         expr.Sorter
 }
 
-func New(pctx *op.Context, parent zbuf.Puller, fields []expr.Evaluator, order order.Which, nullsFirst bool) (*Proc, error) {
-	return &Proc{
-		pctx:           pctx,
+func New(octx *op.Context, parent zbuf.Puller, fields []expr.Evaluator, order order.Which, nullsFirst bool) (*Op, error) {
+	return &Op{
+		octx:           octx,
 		parent:         parent,
 		order:          order,
 		nullsFirst:     nullsFirst,
@@ -43,17 +43,17 @@ func New(pctx *op.Context, parent zbuf.Puller, fields []expr.Evaluator, order or
 	}, nil
 }
 
-func (p *Proc) Pull(done bool) (zbuf.Batch, error) {
-	p.once.Do(func() {
+func (o *Op) Pull(done bool) (zbuf.Batch, error) {
+	o.once.Do(func() {
 		// Block p.ctx's cancel function until p.run finishes its
 		// cleanup.
-		p.pctx.WaitGroup.Add(1)
-		go p.run()
+		o.octx.WaitGroup.Add(1)
+		go o.run()
 	})
 	for {
-		r, ok := <-p.resultCh
+		r, ok := <-o.resultCh
 		if !ok {
-			return nil, p.pctx.Err()
+			return nil, o.octx.Err()
 		}
 		if !done || r.Batch == nil || r.Err != nil {
 			return r.Batch, r.Err
@@ -62,22 +62,22 @@ func (p *Proc) Pull(done bool) (zbuf.Batch, error) {
 	}
 }
 
-func (p *Proc) run() {
-	defer close(p.resultCh)
+func (o *Op) run() {
+	defer close(o.resultCh)
 	var spiller *spill.MergeSort
 	defer func() {
 		if spiller != nil {
 			spiller.Cleanup()
 		}
 		// Tell p.ctx's cancel function that we've finished our cleanup.
-		p.pctx.WaitGroup.Done()
+		o.octx.WaitGroup.Done()
 	}()
 	var nbytes int
 	var out []zed.Value
 	for {
-		batch, err := p.parent.Pull(false)
+		batch, err := o.parent.Pull(false)
 		if err != nil {
-			if ok := p.sendResult(nil, err); !ok {
+			if ok := o.sendResult(nil, err); !ok {
 				return
 			}
 			continue
@@ -85,11 +85,11 @@ func (p *Proc) run() {
 		if batch == nil {
 			if spiller == nil {
 				if len(out) > 0 {
-					if ok := p.send(out); !ok {
+					if ok := o.send(out); !ok {
 						return
 					}
 				}
-				if ok := p.sendResult(nil, nil); !ok {
+				if ok := o.sendResult(nil, nil); !ok {
 					return
 				}
 				nbytes = 0
@@ -97,8 +97,8 @@ func (p *Proc) run() {
 				continue
 			}
 			if len(out) > 0 {
-				if err := spiller.Spill(p.pctx.Context, out); err != nil {
-					if ok := p.sendResult(nil, err); !ok {
+				if err := spiller.Spill(o.octx.Context, out); err != nil {
+					if ok := o.sendResult(nil, err); !ok {
 						return
 					}
 					spiller = nil
@@ -107,7 +107,7 @@ func (p *Proc) run() {
 					continue
 				}
 			}
-			if ok := p.sendSpills(spiller); !ok {
+			if ok := o.sendSpills(spiller); !ok {
 				return
 			}
 			spiller.Cleanup()
@@ -117,20 +117,20 @@ func (p *Proc) run() {
 			continue
 		}
 		// Safe because batch.Unref is never called.
-		p.lastBatch = batch
+		o.lastBatch = batch
 		var delta int
-		out, delta = p.append(out, batch)
-		if p.comparator == nil && len(out) > 0 {
-			p.setComparator(&out[0])
+		out, delta = o.append(out, batch)
+		if o.comparator == nil && len(out) > 0 {
+			o.setComparator(&out[0])
 		}
 		nbytes += delta
 		if nbytes < MemMaxBytes {
 			continue
 		}
 		if spiller == nil {
-			spiller, err = spill.NewMergeSort(p.comparator)
+			spiller, err = spill.NewMergeSort(o.comparator)
 			if err != nil {
-				if ok := p.sendResult(nil, err); !ok {
+				if ok := o.sendResult(nil, err); !ok {
 					return
 				}
 				out = nil
@@ -138,8 +138,8 @@ func (p *Proc) run() {
 				continue
 			}
 		}
-		if err := spiller.Spill(p.pctx.Context, out); err != nil {
-			if ok := p.sendResult(nil, err); !ok {
+		if err := spiller.Spill(o.octx.Context, out); err != nil {
+			if ok := o.sendResult(nil, err); !ok {
 				return
 			}
 		}
@@ -149,21 +149,21 @@ func (p *Proc) run() {
 }
 
 // send sorts vals in memory and sends the result downstream.
-func (p *Proc) send(vals []zed.Value) bool {
-	p.sorter.SortStable(vals, p.comparator)
-	out := zbuf.NewBatch(p.lastBatch, vals)
-	return p.sendResult(out, nil)
+func (o *Op) send(vals []zed.Value) bool {
+	o.sorter.SortStable(vals, o.comparator)
+	out := zbuf.NewBatch(o.lastBatch, vals)
+	return o.sendResult(out, nil)
 }
 
-func (p *Proc) sendSpills(spiller *spill.MergeSort) bool {
+func (o *Op) sendSpills(spiller *spill.MergeSort) bool {
 	puller := zbuf.NewPuller(spiller)
 	for {
-		if err := p.pctx.Err(); err != nil {
+		if err := o.octx.Err(); err != nil {
 			return false
 		}
 		// Reading from the spiller merges the spilt files.
 		b, err := puller.Pull(false)
-		if ok := p.sendResult(b, err); !ok {
+		if ok := o.sendResult(b, err); !ok {
 			return false
 		}
 		if b == nil || err != nil {
@@ -172,16 +172,16 @@ func (p *Proc) sendSpills(spiller *spill.MergeSort) bool {
 	}
 }
 
-func (p *Proc) sendResult(b zbuf.Batch, err error) bool {
+func (o *Op) sendResult(b zbuf.Batch, err error) bool {
 	select {
-	case p.resultCh <- op.Result{Batch: b, Err: err}:
+	case o.resultCh <- op.Result{Batch: b, Err: err}:
 		return true
-	case <-p.pctx.Done():
+	case <-o.octx.Done():
 		return false
 	}
 }
 
-func (p *Proc) append(out []zed.Value, batch zbuf.Batch) ([]zed.Value, int) {
+func (o *Op) append(out []zed.Value, batch zbuf.Batch) ([]zed.Value, int) {
 	var nbytes int
 	vals := batch.Values()
 	for i := range vals {
@@ -193,19 +193,19 @@ func (p *Proc) append(out []zed.Value, batch zbuf.Batch) ([]zed.Value, int) {
 	return out, nbytes
 }
 
-func (p *Proc) setComparator(r *zed.Value) {
-	resolvers := p.fieldResolvers
+func (o *Op) setComparator(r *zed.Value) {
+	resolvers := o.fieldResolvers
 	if resolvers == nil {
 		fld := GuessSortKey(r)
-		resolver := expr.NewDottedExpr(p.pctx.Zctx, fld)
+		resolver := expr.NewDottedExpr(o.octx.Zctx, fld)
 		resolvers = []expr.Evaluator{resolver}
 	}
-	reverse := p.order == order.Desc
-	nullsMax := !p.nullsFirst
+	reverse := o.order == order.Desc
+	nullsMax := !o.nullsFirst
 	if reverse {
 		nullsMax = !nullsMax
 	}
-	p.comparator = expr.NewComparator(nullsMax, reverse, resolvers...).WithMissingAsNull()
+	o.comparator = expr.NewComparator(nullsMax, reverse, resolvers...).WithMissingAsNull()
 }
 
 func GuessSortKey(val *zed.Value) field.Path {
