@@ -6,9 +6,6 @@ import (
 	"sync/atomic"
 
 	"github.com/brimdata/zed"
-	"github.com/brimdata/zed/compiler/ast/dag"
-	"github.com/brimdata/zed/order"
-	"github.com/brimdata/zed/pkg/field"
 	"github.com/brimdata/zed/runtime/expr"
 	"github.com/brimdata/zed/zio"
 )
@@ -16,14 +13,6 @@ import (
 type Filter interface {
 	AsEvaluator() (expr.Evaluator, error)
 	AsBufferFilter() (*expr.BufferFilter, error)
-	AsKeySpanFilter(field.Path, order.Which) (*expr.SpanFilter, error)
-	AsKeyCroppedByFilter(field.Path, order.Which) (*expr.SpanFilter, error)
-	//XXX This is here to break an import loop between lake and compiler.
-	// We will remove this in a subsequent PR when the runtime/sequence,vector
-	// packages will implement a pushdown language that is not based on dag.Expr
-	// and the compiler will allocate runtime planner entities that know
-	// their pushdown directly.
-	Pushdown() dag.Expr
 }
 
 // ScannerAble is implemented by Readers that provide an optimized
@@ -79,8 +68,6 @@ func (p *Progress) Progress() Progress {
 	return p.Copy()
 }
 
-var ScannerBatchSize = 100
-
 // NewScanner returns a Scanner for r that filters records by filterExpr and s.
 // If r implements fmt.Stringer, the scanner reports errors using a prefix of the
 // string returned by its String method.
@@ -113,7 +100,7 @@ func newScanner(ctx context.Context, r zio.Reader, filterExpr Filter) (Scanner,
 		}
 	}
 	sc := &scanner{reader: r, filter: f, ctx: ctx}
-	sc.Puller = NewPuller(sc, ScannerBatchSize)
+	sc.Puller = NewPuller(sc)
 	return sc, nil
 }
 
