@@ -7,6 +7,7 @@ import (
 	astzed "github.com/brimdata/zed/compiler/ast/zed"
 	"github.com/brimdata/zed/compiler/kernel"
 	"github.com/brimdata/zed/order"
+	"github.com/brimdata/zed/zson"
 )
 
 func DAG(op dag.Op) string {
@@ -99,6 +100,25 @@ func (c *canonDAG) expr(e dag.Expr, parent string) {
 		c.write("%s(", e.Name)
 		c.exprs(e.Args)
 		c.write(")")
+	case *dag.OverExpr:
+		c.open("(")
+		c.ret()
+		c.write("over ")
+		c.exprs(e.Exprs)
+		if len(e.Defs) > 0 {
+			for i, d := range e.Defs {
+				if i > 0 {
+					c.write(", ")
+				}
+				c.write("%s=", d.Name)
+				c.expr(d.Expr, "")
+			}
+		}
+		c.op(e.Scope)
+		c.close()
+		c.ret()
+		c.flush()
+		c.write(")")
 	case *dag.Search:
 		c.write("search(%s)", e.Value)
 	case *dag.This:
@@ -111,6 +131,44 @@ func (c *canonDAG) expr(e dag.Expr, parent string) {
 		c.write("type<")
 		c.typ(e.Value)
 		c.write(">")
+	case *dag.RecordExpr:
+		c.write("{")
+		for k, elem := range e.Elems {
+			if k > 0 {
+				c.write(",")
+			}
+			switch e := elem.(type) {
+			case *dag.Field:
+				c.write(zson.QuotedName(e.Name))
+				c.write(":")
+				c.expr(e.Value, "")
+			case *dag.Spread:
+				c.write("...")
+				c.expr(e.Expr, "")
+			default:
+				c.write("zfmt: unknown record elem type: %T", e)
+			}
+		}
+		c.write("}")
+	case *dag.ArrayExpr:
+		c.write("[")
+		c.vectorElems(e.Elems)
+		c.write("]")
+	case *dag.SetExpr:
+		c.write("|[")
+		c.vectorElems(e.Elems)
+		c.write("]|")
+	case *dag.MapExpr:
+		c.write("|{")
+		for k, e := range e.Entries {
+			if k > 0 {
+				c.write(",")
+			}
+			c.expr(e.Key, "")
+			c.write(":")
+			c.expr(e.Value, "")
+		}
+		c.write("}|")
 	default:
 		c.open("(unknown expr %T)", e)
 		c.close()
@@ -152,6 +210,23 @@ func (c *canonDAG) binary(e *dag.BinaryExpr, parent string) {
 	}
 }
 
+func (c *canonDAG) vectorElems(elems []dag.VectorElem) {
+	for k, elem := range elems {
+		if k > 0 {
+			c.write(",")
+		}
+		switch elem := elem.(type) {
+		case *dag.Spread:
+			c.write("...")
+			c.expr(elem.Expr, "")
+		case *dag.VectorValue:
+			c.expr(elem.Expr, "")
+		default:
+			c.write("zfmt: unknown vector elem type: %T", elem)
+		}
+	}
+}
+
 func isDAGThis(e dag.Expr) bool {
 	if this, ok := e.(*dag.This); ok {
 		if len(this.Path) == 0 {
@@ -379,10 +454,10 @@ func (c *canonDAG) op(p dag.Op) {
 		c.ret()
 		c.close()
 		c.write(")")
+	case *dag.Let:
+		c.over(p.Over, p.Defs)
 	case *dag.Over:
-		c.next()
-		c.write("over ")
-		c.exprs(p.Exprs)
+		c.over(p, nil)
 	case *dag.Yield:
 		c.next()
 		c.write("yield ")
@@ -393,6 +468,32 @@ func (c *canonDAG) op(p dag.Op) {
 	}
 }
 
+func (c *canonDAG) over(o *dag.Over, locals []dag.Def) {
+	c.next()
+	c.write("over ")
+	c.exprs(o.Exprs)
+	if len(locals) > 0 {
+		c.write(" with ")
+		for i, l := range locals {
+			if i > 0 {
+				c.write(", ")
+			}
+			c.write("%s=", l.Name)
+			c.expr(l.Expr, "")
+		}
+	}
+	if o.Scope != nil {
+		c.write(" => (")
+		c.open()
+		c.head = true
+		c.op(o.Scope)
+		c.close()
+		c.ret()
+		c.flush()
+		c.write(")")
+	}
+}
+
 func source(src dag.Source) string {
 	switch p := src.(type) {
 	case *dag.File:
