@@ -85,24 +85,24 @@ func (e *Encoder) encode(ext zed.Type) (zed.Type, error) {
 }
 
 func (e *Encoder) encodeTypeRecord(ext *zed.TypeRecord) (zed.Type, error) {
-	var columns []zed.Column
-	for _, col := range ext.Columns {
-		child, err := e.Encode(col.Type)
+	var fields []zed.Field
+	for _, f := range ext.Fields {
+		child, err := e.Encode(f.Type)
 		if err != nil {
 			return nil, err
 		}
-		columns = append(columns, zed.NewColumn(col.Name, child))
+		fields = append(fields, zed.NewField(f.Name, child))
 	}
-	typ, err := e.zctx.LookupTypeRecord(columns)
+	typ, err := e.zctx.LookupTypeRecord(fields)
 	if err != nil {
 		return nil, err
 	}
 	e.bytes = append(e.bytes, TypeDefRecord)
-	e.bytes = binary.AppendUvarint(e.bytes, uint64(len(columns)))
-	for _, col := range columns {
-		e.bytes = binary.AppendUvarint(e.bytes, uint64(len(col.Name)))
-		e.bytes = append(e.bytes, col.Name...)
-		e.bytes = binary.AppendUvarint(e.bytes, uint64(zed.TypeID(col.Type)))
+	e.bytes = binary.AppendUvarint(e.bytes, uint64(len(fields)))
+	for _, f := range fields {
+		e.bytes = binary.AppendUvarint(e.bytes, uint64(len(f.Name)))
+		e.bytes = append(e.bytes, f.Name...)
+		e.bytes = binary.AppendUvarint(e.bytes, uint64(zed.TypeID(f.Type)))
 	}
 	return typ, nil
 }
@@ -266,19 +266,19 @@ func (d *Decoder) decode(b *buffer) error {
 }
 
 func (d *Decoder) readTypeRecord(b *buffer) error {
-	ncol, err := readUvarintAsInt(b)
+	nfields, err := readUvarintAsInt(b)
 	if err != nil {
-		return zed.ErrBadFormat
+		return errBadFormat
 	}
-	var columns []zed.Column
-	for k := 0; k < int(ncol); k++ {
-		col, err := d.readColumn(b)
+	var fields []zed.Field
+	for k := 0; k < int(nfields); k++ {
+		f, err := d.readField(b)
 		if err != nil {
 			return err
 		}
-		columns = append(columns, col)
+		fields = append(fields, f)
 	}
-	typ, err := d.local.zctx.LookupTypeRecord(columns)
+	typ, err := d.local.zctx.LookupTypeRecord(fields)
 	if err != nil {
 		return err
 	}
@@ -286,26 +286,26 @@ func (d *Decoder) readTypeRecord(b *buffer) error {
 	return err
 }
 
-func (d *Decoder) readColumn(b *buffer) (zed.Column, error) {
+func (d *Decoder) readField(b *buffer) (zed.Field, error) {
 	name, err := d.readCountedString(b)
 	if err != nil {
-		return zed.Column{}, err
+		return zed.Field{}, err
 	}
 	id, err := readUvarintAsInt(b)
 	if err != nil {
-		return zed.Column{}, zed.ErrBadFormat
+		return zed.Field{}, errBadFormat
 	}
 	typ, err := d.local.zctx.LookupType(id)
 	if err != nil {
-		return zed.Column{}, err
+		return zed.Field{}, err
 	}
-	return zed.NewColumn(name, typ), nil
+	return zed.NewField(name, typ), nil
 }
 
 func (d *Decoder) readTypeArray(b *buffer) error {
 	id, err := readUvarintAsInt(b)
 	if err != nil {
-		return zed.ErrBadFormat
+		return errBadFormat
 	}
 	inner, err := d.local.zctx.LookupType(int(id))
 	if err != nil {
@@ -319,7 +319,7 @@ func (d *Decoder) readTypeArray(b *buffer) error {
 func (d *Decoder) readTypeSet(b *buffer) error {
 	id, err := readUvarintAsInt(b)
 	if err != nil {
-		return zed.ErrBadFormat
+		return errBadFormat
 	}
 	innerType, err := d.local.zctx.LookupType(int(id))
 	if err != nil {
@@ -333,7 +333,7 @@ func (d *Decoder) readTypeSet(b *buffer) error {
 func (d *Decoder) readTypeMap(b *buffer) error {
 	id, err := readUvarintAsInt(b)
 	if err != nil {
-		return zed.ErrBadFormat
+		return errBadFormat
 	}
 	keyType, err := d.local.zctx.LookupType(int(id))
 	if err != nil {
@@ -341,7 +341,7 @@ func (d *Decoder) readTypeMap(b *buffer) error {
 	}
 	id, err = readUvarintAsInt(b)
 	if err != nil {
-		return zed.ErrBadFormat
+		return errBadFormat
 	}
 	valType, err := d.local.zctx.LookupType(int(id))
 	if err != nil {
@@ -355,16 +355,16 @@ func (d *Decoder) readTypeMap(b *buffer) error {
 func (d *Decoder) readTypeUnion(b *buffer) error {
 	ntyp, err := readUvarintAsInt(b)
 	if err != nil {
-		return zed.ErrBadFormat
+		return errBadFormat
 	}
 	if ntyp == 0 {
-		return errors.New("type union: zero columns not allowed")
+		return errors.New("type union: zero types not allowed")
 	}
 	var types []zed.Type
 	for k := 0; k < int(ntyp); k++ {
 		id, err := readUvarintAsInt(b)
 		if err != nil {
-			return zed.ErrBadFormat
+			return errBadFormat
 		}
 		typ, err := d.local.zctx.LookupType(int(id))
 		if err != nil {
@@ -380,7 +380,7 @@ func (d *Decoder) readTypeUnion(b *buffer) error {
 func (d *Decoder) readTypeEnum(b *buffer) error {
 	nsym, err := readUvarintAsInt(b)
 	if err != nil {
-		return zed.ErrBadFormat
+		return errBadFormat
 	}
 	var symbols []string
 	for k := 0; k < int(nsym); k++ {
@@ -398,11 +398,11 @@ func (d *Decoder) readTypeEnum(b *buffer) error {
 func (d *Decoder) readCountedString(b *buffer) (string, error) {
 	n, err := readUvarintAsInt(b)
 	if err != nil {
-		return "", zed.ErrBadFormat
+		return "", errBadFormat
 	}
 	name, err := b.read(n)
 	if err != nil {
-		return "", zed.ErrBadFormat
+		return "", errBadFormat
 	}
 	// pull the name out before the next read which might overwrite the buffer
 	return string(name), nil
@@ -415,7 +415,7 @@ func (d *Decoder) readTypeName(b *buffer) error {
 	}
 	id, err := readUvarintAsInt(b)
 	if err != nil {
-		return zed.ErrBadFormat
+		return errBadFormat
 	}
 	inner, err := d.local.zctx.LookupType(int(id))
 	if err != nil {
@@ -432,7 +432,7 @@ func (d *Decoder) readTypeName(b *buffer) error {
 func (d *Decoder) readTypeError(b *buffer) error {
 	id, err := readUvarintAsInt(b)
 	if err != nil {
-		return zed.ErrBadFormat
+		return errBadFormat
 	}
 	inner, err := d.local.zctx.LookupType(int(id))
 	if err != nil {
